Changelog
=========


1.1.4 (2025-01-07)
------------------

- WEB-4153: Set moderateCaching for imio.directory.core.rest
  [remdub]

- GHA tests on Python 3.8 3.9 and 3.10
  [remdub]


1.1.3 (2023-10-09)
------------------

- WEB-3954 : Hide cropping action on Image type
  [boulch]

- Migrate to Plone 6.0.4
  [boulch]


1.1.2 (2023-04-07)
------------------

- Add module : collective.messagesviewlet
  [boulch]

- Migrate to Plone 6.0.2
  [boulch]


1.1.1 (2023-01-12)
------------------

- Install and configure autopublishing (with 15 min tick subscriber)
  [boulch]

- Remove obsolete TinyMCE override
  [laulaz]

- Remove available languages (we don't need them anymore)
  [laulaz]


1.1 (2022-12-20)
----------------

- Update to Plone 6.0.0 final
  [boulch]


1.0 (2022-11-15)
----------------

- Add available languages to prepare for multilingual
  [laulaz]

- Update buildout to use Plone 6.0.0a3 packages versions
  [boulch]


1.0a1 (2022-01-25)
------------------

- Initial release.
  [laulaz]
